@@ -52,6 +52,8 @@
 
 #include "gnc-backend-dbi.h"
 
+#include "gnc-prefs.h"
+
 #ifdef S_SPLINT_S
 #include "splint-defs.h"
 #endif
@@ -65,6 +67,13 @@
 #define GETPID() getpid()
 #endif
 
+#if LIBDBI_VERSION >= 900
+#define HAVE_LIBDBI_R 1
+static dbi_inst dbi_instance = NULL;
+#else
+#define HAVE_LIBDBI_R 0
+#endif
+
 /* For direct access to dbi data structs, sadly needed for datetime */
 #include <dbi/dbi-dev.h>
 
@@ -281,7 +290,16 @@ gnc_dbi_sqlite3_session_begin( QofBackend *qbe, QofSession *session,
     {
         dbi_conn_close( be->conn );
     }
+
+    #if HAVE_LIBDBI_R
+    if (dbi_instance)
+        be->conn = dbi_conn_new_r( "sqlite3", dbi_instance );
+    else
+        PERR ("Attempt to connect with an uninitialized dbi_instance");
+    #else
     be->conn = dbi_conn_new( "sqlite3" );
+    #endif
+
     if ( be->conn == NULL )
     {
         PERR( "Unable to create sqlite3 dbi connection\n" );
@@ -806,7 +824,14 @@ gnc_dbi_mysql_session_begin( QofBackend* qbe, QofSession *session,
     {
         dbi_conn_close( be->conn );
     }
+#if HAVE_LIBDBI_R
+    if (dbi_instance)
+        be->conn = dbi_conn_new_r( "mysql", dbi_instance );
+    else
+        PERR ("Attempt to connect with an uninitialized dbi_instance");
+#else
     be->conn = dbi_conn_new( "mysql" );
+#endif
     if ( be->conn == NULL )
     {
         PERR( "Unable to create mysql dbi connection\n" );
@@ -891,7 +916,15 @@ gnc_dbi_mysql_session_begin( QofBackend* qbe, QofSession *session,
             dbi_conn_close( be->conn );
 
             // Try again to connect to the db
+            #if HAVE_LIBDBI_R
+	    if (dbi_instance)
+	        be->conn = dbi_conn_new_r( "mysql", dbi_instance );
+	    else
+	        PERR ("Attempt to connect with an uninitialized dbi_instance");
+            #else
             be->conn = dbi_conn_new( "mysql" );
+            #endif
+
             if ( be->conn == NULL )
             {
                 PERR( "Unable to create mysql dbi connection\n" );
@@ -1142,7 +1175,16 @@ gnc_dbi_postgres_session_begin( QofBackend *qbe, QofSession *session,
     {
         dbi_conn_close( be->conn );
     }
+
+    #if HAVE_LIBDBI_R
+    if (dbi_instance)
+        be->conn = dbi_conn_new_r( "pgsql", dbi_instance );
+    else
+        PERR ("Attempt to connect with an uninitialized dbi_instance");
+    #else
     be->conn = dbi_conn_new( "pgsql" );
+    #endif
+
     if ( be->conn == NULL )
     {
         PERR( "Unable to create pgsql dbi connection\n" );
@@ -1228,7 +1270,15 @@ gnc_dbi_postgres_session_begin( QofBackend *qbe, QofSession *session,
             dbi_conn_close( be->conn );
 
             // Try again to connect to the db
+            #if HAVE_LIBDBI_R
+            if (dbi_instance)
+                be->conn = dbi_conn_new_r( "pgsql", dbi_instance );
+            else
+	        PERR ("Attempt to connect with an uninitialized dbi_instance");
+            #else
             be->conn = dbi_conn_new( "pgsql" );
+            #endif
+
             if ( be->conn == NULL )
             {
                 PERR( "Unable to create pgsql dbi connection\n" );
@@ -1409,7 +1459,7 @@ gnc_dbi_load( QofBackend* qbe, /*@ dependent @*/ QofBook *book, QofBackendLoadTy
         be->primary_book = book;
 
         // Set up table version information
-        gnc_sql_init_version_info( &be->sql_be );
+        gnc_sql_init_version_info (&be->sql_be);
 
         // Call all object backends to create any required tables
         qof_object_foreach_backend( GNC_SQL_BACKEND, create_tables_cb, be );
@@ -1833,7 +1883,13 @@ gnc_module_init_backend_dbi(void)
     }
 
     /* dbi_initialize returns -1 in case of errors */
+    #if HAVE_LIBDBI_R
+    if (dbi_instance)
+        return;
+    num_drivers = dbi_initialize_r( driver_dir, &dbi_instance );
+    #else
     num_drivers = dbi_initialize( driver_dir );
+    #endif
     if ( num_drivers <= 0 )
     {
         PWARN( "No DBD drivers found\n" );
@@ -1845,7 +1901,12 @@ gnc_module_init_backend_dbi(void)
 
         do
         {
+            #if HAVE_LIBDBI_R
+            driver = dbi_driver_list_r( driver, dbi_instance );
+            #else
             driver = dbi_driver_list( driver );
+            #endif
+
             if ( driver != NULL )
             {
                 const gchar* name = dbi_driver_get_name( driver );
@@ -1943,7 +2004,15 @@ qof_backend_module_finalize( void )
 void
 gnc_module_finalize_backend_dbi( void )
 {
+#if HAVE_LIBDBI_R
+  if (dbi_instance)
+  {
+      dbi_shutdown_r(dbi_instance);
+      dbi_instance = NULL;
+  }
+#else
     dbi_shutdown();
+#endif
 }
 
 /* --------------------------------------------------------- */
