@@ -426,7 +426,7 @@ account_lots_handler(xmlNodePtr node, gpointer act_pdata)
     {
         GNCLot *lot;
 
-        if (safe_strcmp("text", (char*) mark->name) == 0)
+        if (g_strcmp0("text", (char*) mark->name) == 0)
             continue;
 
         lot = dom_tree_to_lot(mark, pdata->book);
@@ -475,14 +475,12 @@ gnc_account_end_handler(gpointer data_for_children,
                         gpointer parent_data, gpointer global_data,
                         gpointer *result, const gchar *tag)
 {
-    int successful;
     Account *acc, *parent, *root;
     xmlNodePtr tree = (xmlNodePtr)data_for_children;
     gxpf_data *gdata = (gxpf_data*)global_data;
     QofBook *book = gdata->bookdata;
     int type;
 
-    successful = TRUE;
 
     if (parent_data)
     {
