@@ -58,7 +58,7 @@ struct timeval
 #include "gnc-lot.h"
 #include "gnc-event.h"
 #include <gnc-gdate-utils.h>
-
+#include "SchedXaction.h"
 #include "qofbackend-p.h"
 
 /* Notes about xaccTransBeginEdit(), xaccTransCommitEdit(), and
@@ -2236,6 +2236,19 @@ xaccTransGetReadOnly (const Transaction *trans)
                trans->inst.kvp_data, TRANS_READ_ONLY_REASON) : NULL;
 }
 
+static gboolean
+xaccTransIsSXTemplate (const Transaction * trans)
+{
+    Split *split0 = xaccTransGetSplit (trans, 0);
+    if (split0 != NULL)
+    {
+	KvpFrame *split_frame = xaccSplitGetSlots (split0);
+	if (kvp_frame_get_frame(split_frame, GNC_SX_ID))
+	    return TRUE;
+    }
+    return FALSE;
+}
+
 gboolean xaccTransIsReadonlyByPostedDate(const Transaction *trans)
 {
     GDate *threshold_date;
@@ -2249,6 +2262,9 @@ gboolean xaccTransIsReadonlyByPostedDate(const Transaction *trans)
         return FALSE;
     }
 
+    if (xaccTransIsSXTemplate (trans))
+	return FALSE;
+
     threshold_date = qof_book_get_autoreadonly_gdate(book);
     g_assert(threshold_date); // ok because we checked uses_autoreadonly before
     trans_date = xaccTransGetDatePostedGDate(trans);
