@@ -486,7 +486,7 @@ test_xaccMallocTransaction (Fixture *fixture, gconstpointer pData)
     QofBook *book = qof_book_new ();
     TestSignal sig1 = test_signal_new (NULL, QOF_EVENT_CREATE,NULL);
     Transaction *txn;
-#ifdef __clang__
+#if defined(__clang__) && __clang_major__ < 6
 #define _func "Transaction *xaccMallocTransaction(QofBook *)"
 #else
 #define _func "xaccMallocTransaction"
@@ -1272,7 +1272,7 @@ xaccTransGetAccountBalance (const Transaction *trans,// C: 1  Local: 0:0:0
 static void
 test_xaccTransGetAccountBalance (Fixture *fixture, gconstpointer pData)
 {
-#ifdef __clang__
+#if defined(__clang__) && __clang_major__ < 6
 #define _func "gnc_numeric xaccTransGetAccountBalance(const Transaction *, const Account *)"
 #else
 #define _func "xaccTransGetAccountBalance"
