@@ -82,7 +82,12 @@ G_MODULE_EXPORT void gnc_ab_trans_dialog_moveup_templ_cb(GtkButton *button, gpoi
 G_MODULE_EXPORT void gnc_ab_trans_dialog_movedown_templ_cb(GtkButton *button, gpointer user_data);
 G_MODULE_EXPORT void gnc_ab_trans_dialog_sort_templ_cb(GtkButton *button, gpointer user_data);
 G_MODULE_EXPORT void gnc_ab_trans_dialog_del_templ_cb(GtkButton *button, gpointer user_data);
-G_MODULE_EXPORT void gnc_ab_trans_dialog_entry_filter_cb (GtkEditable *editable,
+G_MODULE_EXPORT void gnc_ab_trans_dialog_ibanentry_filter_cb (GtkEditable *editable,
+        const gchar *text,
+        gint         length,
+        gint        *position,
+        gpointer     user_data);
+G_MODULE_EXPORT void gnc_ab_trans_dialog_bicentry_filter_cb (GtkEditable *editable,
         const gchar *text,
         gint         length,
         gint        *position,
@@ -128,6 +133,9 @@ struct _GncABTransDialog
     /* Recipient's bank name (may be filled in automatically sometime later) */
     GtkWidget *recp_bankname_label;
 
+    /* Originator's name (might have to be edited by the user) */
+    GtkWidget *orig_name_entry;
+
     /* The template choosing GtkTreeView/GtkListStore */
     GtkTreeView *template_gtktreeview;
     GtkListStore *template_list_store;
@@ -200,6 +208,8 @@ gnc_ab_trans_dialog_fill_values(GncABTransDialog *td)
                     trans, gtk_entry_get_text(GTK_ENTRY(td->recp_bankcode_entry)));
         AB_Transaction_SetRemoteIban(
                     trans, gtk_entry_get_text(GTK_ENTRY(td->recp_account_entry)));
+        AB_Transaction_SetLocalName(
+                    trans, gtk_entry_get_text(GTK_ENTRY(td->orig_name_entry)));
     }
     else
     {
@@ -263,7 +273,6 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     GtkWidget *recp_bankcode_heading;
     GtkWidget *amount_hbox;
     GtkWidget *orig_name_heading;
-    GtkWidget *orig_name_label;
     GtkWidget *orig_account_heading;
     GtkWidget *orig_account_label;
     G_GNUC_UNUSED GtkWidget *orig_bankname_heading;
@@ -317,7 +326,7 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     td->purpose_cont3_entry = GTK_WIDGET(gtk_builder_get_object (builder, "purpose_cont3_entry"));
     td->exec_button = GTK_WIDGET(gtk_builder_get_object(builder, "exec_now_button"));
     orig_name_heading = GTK_WIDGET(gtk_builder_get_object (builder, "orig_name_heading"));
-    orig_name_label = GTK_WIDGET(gtk_builder_get_object (builder, "orig_name_label"));
+    td->orig_name_entry = GTK_WIDGET(gtk_builder_get_object (builder, "orig_name_label"));
     orig_account_heading = GTK_WIDGET(gtk_builder_get_object (builder, "orig_account_heading"));
     orig_account_label = GTK_WIDGET(gtk_builder_get_object (builder, "orig_account_label"));
     orig_bankname_heading = GTK_WIDGET(gtk_builder_get_object (builder, "orig_bankname_heading"));
@@ -345,11 +354,9 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     {
     case SINGLE_TRANSFER:
     case SINGLE_INTERNAL_TRANSFER:
-    case SEPA_TRANSFER:
         /* all labels are already set */
         break;
-    case SINGLE_DEBITNOTE:
-    case SEPA_DEBITNOTE:
+    case SEPA_TRANSFER:
         gtk_label_set_text(GTK_LABEL (heading_label),
                            /* Translators: Strings from this file are
                              * needed only in countries that have one of
@@ -361,6 +368,20 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
                              * country, you may safely ignore strings
                              * from the import-export/hbci
                              * subdirectory. */
+                           _("Enter a SEPA Online Transfer"));
+        gtk_label_set_text(GTK_LABEL(recp_account_heading),
+                           _("Recipient IBAN (International Account Number)"));
+        gtk_label_set_text(GTK_LABEL(recp_bankcode_heading),
+                           _("Recipient BIC (Bank Code)"));
+
+        gtk_label_set_text(GTK_LABEL(orig_account_heading),
+                           _("Originator IBAN (International Account Number)"));
+        gtk_label_set_text(GTK_LABEL(orig_bankcode_heading),
+                           _("Originator BIC (Bank Code)"));
+        break;
+
+    case SINGLE_DEBITNOTE:
+        gtk_label_set_text(GTK_LABEL (heading_label),
                            _("Enter an Online Direct Debit Note"));
 
         gtk_label_set_text(GTK_LABEL(recp_name_heading),
@@ -378,6 +399,25 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
                            _("Credited Account Bank Code"));
         break;
 
+    case SEPA_DEBITNOTE:
+        gtk_label_set_text(GTK_LABEL (heading_label),
+                           _("Enter a SEPA Online Direct Debit Note"));
+
+        gtk_label_set_text(GTK_LABEL(recp_name_heading),
+                           _("Debited Account Owner"));
+        gtk_label_set_text(GTK_LABEL(recp_account_heading),
+                           _("Debited IBAN (International Account Number)"));
+        gtk_label_set_text(GTK_LABEL(recp_bankcode_heading),
+                           _("Debited BIC (Bank Code)"));
+
+        gtk_label_set_text(GTK_LABEL(orig_name_heading),
+                           _("Credited Account Owner"));
+        gtk_label_set_text(GTK_LABEL(orig_account_heading),
+                           _("Credited IBAN (International Account Number)"));
+        gtk_label_set_text(GTK_LABEL(orig_bankcode_heading),
+                           _("Credited BIC (Bank Code)"));
+        break;
+
     default:
         g_critical("gnc_ab_trans_dialog_new: Oops, unknown GncABTransType %d",
                    trans_type);
@@ -385,24 +425,6 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     }
 
     /* Additionally change the labels for the European (SEPA) transactions */
-    switch (trans_type)
-    {
-    case SEPA_TRANSFER:
-        gtk_label_set_text(GTK_LABEL(recp_account_heading),
-                           _("Recipient IBAN (International Account Number)"));
-        gtk_label_set_text(GTK_LABEL(recp_bankcode_heading),
-                           _("Recipient BIC (Bank Code)"));
-        break;
-    case SEPA_DEBITNOTE:
-        gtk_label_set_text(GTK_LABEL(recp_account_heading),
-                           _("Debited IBAN (International Account Number)"));
-        gtk_label_set_text(GTK_LABEL(recp_bankcode_heading),
-                           _("Debited BIC (Bank Code)"));
-        break;
-    default:
-        // do nothing
-        break;
-    }
     if (gnc_ab_trans_isSEPA(trans_type))
     {
         // Also, SEPA might have much longer IBAN (up to 34 chars) and BIC (11)
@@ -410,10 +432,22 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
         gtk_entry_set_max_length(GTK_ENTRY(td->recp_account_entry), 34);
     }
 
-    gtk_label_set_text(GTK_LABEL(orig_name_label), ab_ownername);
-    gtk_label_set_text(GTK_LABEL(orig_account_label), ab_accountnumber);
+    gtk_entry_set_text(GTK_ENTRY(td->orig_name_entry), ab_ownername);
     gtk_label_set_text(GTK_LABEL(orig_bankname_label), ab_bankname);
-    gtk_label_set_text (GTK_LABEL (orig_bankcode_label), ab_bankcode);
+    if (gnc_ab_trans_isSEPA(trans_type))
+    {
+        gtk_widget_set_sensitive(GTK_WIDGET(td->orig_name_entry), TRUE);
+        ab_accountnumber = AB_Account_GetIBAN(ab_acc);
+        ab_bankcode = AB_Account_GetBIC(ab_acc);
+        gtk_label_set_text(GTK_LABEL(orig_account_label), ab_accountnumber);
+        gtk_label_set_text (GTK_LABEL (orig_bankcode_label), ab_bankcode);
+    }
+    else
+    {
+        gtk_widget_set_sensitive(GTK_WIDGET(td->orig_name_entry), FALSE);
+        gtk_label_set_text(GTK_LABEL(orig_account_label), ab_accountnumber);
+        gtk_label_set_text (GTK_LABEL (orig_bankcode_label), ab_bankcode);
+    }
 
     /* Fill list for choosing a transaction template */
     td->template_list_store = gtk_list_store_new(TEMPLATE_NUM_COLUMNS,
@@ -456,6 +490,27 @@ static void
 gnc_ab_trans_dialog_check_ktoblzcheck(const GncABTransDialog *td,
                                       const AB_TRANSACTION *trans)
 {
+    if (gnc_ab_trans_isSEPA(td->trans_type))
+    {
+        int rv = AB_Banking_CheckIban(AB_Transaction_GetRemoteIban(trans));
+        if (rv != 0) {
+            gchar *message = g_strdup_printf(_("The internal check of the destination IBAN '%s' "
+                                               "failed. This means "
+                                               "the account number might contain an error."),
+                                             AB_Transaction_GetRemoteIban(trans));
+            gnc_ab_trans_dialog_entry_set (td->recp_account_entry, message,
+                                           GTK_STOCK_DIALOG_WARNING);
+        }
+        else
+        {
+            gnc_ab_trans_dialog_entry_set (td->recp_account_entry, "",
+                                           NULL);
+            gnc_ab_trans_dialog_entry_set (td->recp_bankcode_entry, "",
+                                           NULL);
+        }
+    }
+    else
+    {
 #ifndef HAVE_KTOBLZCHECK_H
     return;
 #else
@@ -514,6 +569,7 @@ gnc_ab_trans_dialog_check_ktoblzcheck(const GncABTransDialog *td,
     LEAVE("KtoBlzCheck said check is %d = %s",
           blzresult, blztext ? blztext : "(none)");
 #endif
+    }
 }
 
 static void
@@ -599,7 +655,7 @@ gnc_ab_trans_dialog_verify_values(GncABTransDialog *td)
     bankcode = gnc_ab_trans_isSEPA(td->trans_type)
             ? AB_Transaction_GetRemoteBic(td->ab_trans)
             : AB_Transaction_GetRemoteBankCode(td->ab_trans);
-    if (!bankcode || !strlen(bankcode))
+    if (!gnc_ab_trans_isSEPA(td->trans_type) && (!bankcode || !strlen(bankcode)))
     {
         gnc_ab_trans_dialog_entry_set (td->recp_bankcode_entry,
                                        _("You did not enter a recipient bank. A recipient bank is "
@@ -1271,7 +1327,7 @@ gnc_ab_trans_dialog_del_templ_cb(GtkButton *button, gpointer user_data)
 }
 
 void
-gnc_ab_trans_dialog_entry_filter_cb (GtkEditable *editable,
+gnc_ab_trans_dialog_ibanentry_filter_cb (GtkEditable *editable,
                                      const gchar *text,
                                      gint         length,
                                      gint        *position,
@@ -1283,27 +1339,95 @@ gnc_ab_trans_dialog_entry_filter_cb (GtkEditable *editable,
 
     if (length == -1)
         length = strlen(text);
+    g_assert(position);
+
+    /* Filter digits / non digits as needed */
+    for (i = 0; i < length; i++)
+    {
+        gchar c = text[i];
+
+        if (gnc_ab_trans_isSEPA(td->trans_type))
+        {
+            // SEPA: Only alphas in the first two places (only upper case, though), then only digits
+            if (*position + i < 2)
+            {
+                if (g_ascii_isalpha(c))
+                    g_string_append_c(result, g_ascii_toupper(c));
+            }
+            else
+            {
+                if (g_ascii_isdigit(c))
+                    g_string_append_c(result, c);
+            }
+        }
+        else
+        {
+            // Non-SEPA: Only accept digits.
+            if (g_ascii_isdigit(c))
+            {
+                g_string_append_c(result, c);
+            }
+        }
+    }
+
+    g_signal_handlers_block_by_func (editable,
+                                     (gpointer) gnc_ab_trans_dialog_ibanentry_filter_cb, data);
+    gtk_editable_insert_text (editable, result->str, result->len, position);
+    g_signal_handlers_unblock_by_func (editable,
+                                       (gpointer) gnc_ab_trans_dialog_ibanentry_filter_cb, data);
+    g_signal_stop_emission_by_name (editable, "insert_text");
+    g_string_free (result, TRUE);
+}
+
+void
+gnc_ab_trans_dialog_bicentry_filter_cb (GtkEditable *editable,
+                                     const gchar *text,
+                                     gint         length,
+                                     gint        *position,
+                                     gpointer     data)
+{
+    GString* result = g_string_new(NULL);
+    gint i;
+    GncABTransDialog *td = data;
+
+    if (length == -1)
+        length = strlen(text);
+    g_assert(position);
 
     /* Filter non digits */
     for (i = 0; i < length; i++)
     {
         gchar c = text[i];
 
-        // Only accept digits. FIXME: In the SEPA dialogs, alphanumerics are
-        // allowed, but we could also verify the input according to actual BIC
-        // and IBAN rules. This is not yet done here.
-        if (g_ascii_isdigit(c)
-                || (gnc_ab_trans_isSEPA(td->trans_type) && g_ascii_isalnum(c)))
+        if (gnc_ab_trans_isSEPA(td->trans_type))
         {
-            g_string_append_c(result, c);
+            // SEPA: Only alphas in the first 6 places (only upper case, though), then both upper-case alphas and digits
+            if (*position + i < 6)
+            {
+                if (g_ascii_isalpha(c))
+                    g_string_append_c(result, g_ascii_toupper(c));
+            }
+            else
+            {
+                if (g_ascii_isalnum(c))
+                    g_string_append_c(result, g_ascii_toupper(c));
+            }
+        }
+        else
+        {
+            // Non-SEPA: Only digits accepted.
+            if (g_ascii_isdigit(c))
+            {
+                g_string_append_c(result, c);
+            }
         }
     }
 
     g_signal_handlers_block_by_func (editable,
-                                     (gpointer) gnc_ab_trans_dialog_entry_filter_cb, data);
+                                     (gpointer) gnc_ab_trans_dialog_bicentry_filter_cb, data);
     gtk_editable_insert_text (editable, result->str, result->len, position);
     g_signal_handlers_unblock_by_func (editable,
-                                       (gpointer) gnc_ab_trans_dialog_entry_filter_cb, data);
+                                       (gpointer) gnc_ab_trans_dialog_bicentry_filter_cb, data);
     g_signal_stop_emission_by_name (editable, "insert_text");
     g_string_free (result, TRUE);
 }
