@@ -112,6 +112,29 @@ static gchar *mnemonic_escape (const gchar *source)
     return dest;
 }
 
+static
+void create_regex (GString *regex_str, const gchar *sep)
+{
+    if (!sep) return;
+
+    g_string_printf (regex_str,
+            "\\G(?<type>[^%s]*)%s"
+            "(?<full_name>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<name>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<code>\"(?:[^\"]|\"\")*\"|[^%s]*)%s?"
+            "(?<description>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<color>[^%s]*)%s"
+            "(?<notes>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<commoditym>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<commodityn>\"(?:[^\"]|\"\")*\"|[^%s]*)%s"
+            "(?<hidden>[^%s]*)%s"
+            "(?<tax>[^%s]*)%s"
+            "(?<place_holder>[^%s[:cntrl:]]*)(?:\\R*)",
+            sep, sep, sep, sep, sep, sep, sep, sep, sep, sep, sep, sep,
+            sep, sep, sep, sep, sep, sep, sep, sep, sep, sep, sep);
+
+}
+
 /*************************************************************************/
 
 /**************************************************
@@ -131,17 +154,17 @@ csv_import_file_chooser_confirm_cb (GtkWidget *button, CsvImportInfo *info)
 
     gtk_assistant_set_page_complete (assistant, page, FALSE);
 
-    file_name = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER(info->file_chooser ));
+    file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(info->file_chooser));
 
     if (file_name)
     {
-        gchar *filepath = gnc_uri_get_path ( file_name );
-        gchar *filedir = g_path_get_dirname( filepath );
-        info->starting_dir = g_strdup(filedir);
-        g_free ( filedir );
-        g_free ( filepath );
+        gchar *filepath = gnc_uri_get_path (file_name);
+        gchar *filedir = g_path_get_dirname (filepath);
+        info->starting_dir = g_strdup (filedir);
+        g_free (filedir);
+        g_free (filepath);
 
-        info->file_name = g_strdup(file_name);
+        info->file_name = g_strdup (file_name);
 
         // generate preview
         gtk_list_store_clear (info->store);
@@ -153,13 +176,13 @@ csv_import_file_chooser_confirm_cb (GtkWidget *button, CsvImportInfo *info)
         else if (res == MATCH_FOUND)
             gtk_assistant_set_page_complete (assistant, page, TRUE);
     }
-    g_free(file_name);
+    g_free (file_name);
 
     DEBUG("file_name selected is %s", info->file_name);
     DEBUG("starting directory is %s", info->starting_dir);
 
     /* Step to next page if page is complete */
-    if(gtk_assistant_get_page_complete(assistant, page))
+    if(gtk_assistant_get_page_complete (assistant, page))
         gtk_assistant_set_current_page (assistant, num + 1);
 
 }
@@ -170,7 +193,7 @@ csv_import_file_chooser_confirm_cb (GtkWidget *button, CsvImportInfo *info)
  *
  * call back for the start row / number of header rows
  *******************************************************/
-void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data )
+void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data)
 {
     CsvImportInfo *info = user_data;
 
@@ -182,12 +205,12 @@ void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data )
     info->header_rows = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(spin));
 
     /* Get number of rows displayed */
-    num_rows = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(info->store), NULL);
+    num_rows = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(info->store), NULL);
 
     /* Modify background color for header rows */
     if (info->header_rows == 0)
     {
-        valid = gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(info->store), &iter, NULL, 0 );
+        valid = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL(info->store), &iter, NULL, 0 );
         if (valid)
             gtk_list_store_set (info->store, &iter, ROW_COLOR, NULL, -1);
     }
@@ -195,7 +218,7 @@ void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data )
     {
         if (info->header_rows - 1 < num_rows)
         {
-            valid = gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(info->store), &iter, NULL, info->header_rows - 1 );
+            valid = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL(info->store), &iter, NULL, info->header_rows - 1 );
             if (valid)
                 gtk_list_store_set (info->store, &iter, ROW_COLOR, "pink", -1);
             valid = gtk_tree_model_iter_next (GTK_TREE_MODEL(info->store), &iter);
@@ -211,33 +234,30 @@ void csv_import_hrows_cb (GtkWidget *spin, gpointer user_data )
  *
  * call back for type of separartor required
  *******************************************************/
-void csv_import_sep_cb (GtkWidget *radio, gpointer user_data )
+void csv_import_sep_cb (GtkWidget *radio, gpointer user_data)
 {
     CsvImportInfo *info = user_data;
     const gchar *name;
     gchar *temp;
+    gchar *sep = NULL;
 
-    if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio)))
+    if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(radio)))
     {
         LEAVE("1st callback of pair. Defer to 2nd callback.");
         return;
     }
 
-    name = gtk_buildable_get_name(GTK_BUILDABLE(radio));
+    name = gtk_buildable_get_name (GTK_BUILDABLE(radio));
+    if (g_strcmp0 (name, "radio_semi") == 0)
+        sep = ";";
+    else if (g_strcmp0 (name, "radio_colon") == 0)
+        sep = ":";
+    else
+        sep = ","; /* Use as default as well */
 
-    if (g_strcmp0(name, g_strdup("radio_semi")) == 0)
-        g_string_assign (info->regexp, "^(?<type>[^;]*);(?<full_name>[^;]*);(?<name>[^;]*);(?<code>[^;]*);?(?<description>[^;]*);?(?<color>[^;]*);?(?<notes>[^;]*);?(?<commoditym>[^;]*);?(?<commodityn>[^;]*);?(?<hidden>[^;]*);?(?<tax>[^;]*);?(?<place_holder>[^;]*)$");
+    create_regex (info->regexp, sep);
 
-    if (g_strcmp0(name, g_strdup("radio_comma")) == 0)
-        g_string_assign (info->regexp, "^(?<type>[^,]*),(?<full_name>[^,]*),(?<name>[^,]*),(?<code>[^,]*),?(?<description>[^,]*),?(?<color>[^,]*),?(?<notes>[^,]*),?(?<commoditym>[^,]*),?(?<commodityn>[^,]*),?(?<hidden>[^,]*),?(?<tax>[^,]*),?(?<place_holder>[^,]*)$");
-
-    if (g_strcmp0(name, g_strdup("radio_semiq")) == 0)
-        g_string_assign (info->regexp, "^((?<type>[^\";]*)|\"(?<type>[^\"]*)\");((?<full_name>[^\";]*)|\"(?<full_name>[^\"]*)\");((?<name>[^\";]*)|\"(?<name>[^\"]*)\");((?<code>[^\";]*)|\"(?<code>[^\"]*)\");((?<description>[^\";]*)|\"(?<description>[^\"]*)\");((?<color>[^\";]*)|\"(?<color>[^\"]*)\");((?<notes>[^\";]*)|\"(?<notes>[^\"]*)\");((?<commoditym>[^\";]*)|\"(?<commoditym>[^\"]*)\");((?<commodityn>[^\";]*)|\"(?<commodityn>[^\"]*)\");((?<hidden>[^\";]*)|\"(?<hidden>[^\"]*)\");((?<tax>[^\";]*)|\"(?<tax>[^\"]*)\");((?<place_holder>[^\";]*)|\"(?<place_holder>[^\"]*)\")$");
-
-    if (g_strcmp0(name, g_strdup("radio_commaq")) == 0)
-        g_string_assign (info->regexp, "^((?<type>[^\",]*)|\"(?<type>[^\"]*)\"),((?<full_name>[^\",]*)|\"(?<full_name>[^\"]*)\"),((?<name>[^\",]*)|\"(?<name>[^\"]*)\"),((?<code>[^\",]*)|\"(?<code>[^\"]*)\"),((?<description>[^\",]*)|\"(?<description>[^\"]*)\"),((?<color>[^\",]*)|\"(?<color>[^\"]*)\"),((?<notes>[^\",]*)|\"(?<notes>[^\"]*)\"),((?<commoditym>[^\",]*)|\"(?<commoditym>[^\"]*)\"),((?<commodityn>[^\",]*)|\"(?<commodityn>[^\"]*)\"),((?<hidden>[^\",]*)|\"(?<hidden>[^\"]*)\"),((?<tax>[^\",]*)|\"(?<tax>[^\"]*)\"),((?<place_holder>[^\",]*)|\"(?<place_holder>[^\"]*)\")$");
-
-    if (g_strcmp0(name, g_strdup("radio_custom")) == 0)
+    if (g_strcmp0 (name, "radio_custom") == 0)
     {
         temp = gnc_input_dialog (0, _("Adjust regular expression used for import"), _("This regular expression is used to parse the import file. Modify according to your needs.\n"), info->regexp->str);
         if (temp)
@@ -250,13 +270,13 @@ void csv_import_sep_cb (GtkWidget *radio, gpointer user_data )
     /* Generate preview */
     gtk_list_store_clear (info->store);
 
-    if (csv_import_read_file (info->file_name, info->regexp->str, info->store, 11 ) == MATCH_FOUND)
+    if (csv_import_read_file (info->file_name, info->regexp->str, info->store, 11) == MATCH_FOUND)
         gtk_widget_set_sensitive (info->header_row_spin, TRUE);
     else
         gtk_widget_set_sensitive (info->header_row_spin, FALSE);
 
     /* Reset Header spin to 0 */
-    gtk_spin_button_set_value( GTK_SPIN_BUTTON(info->header_row_spin), 0 );
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON(info->header_row_spin), 0);
 }
 
 
@@ -275,7 +295,7 @@ void load_settings (CsvImportInfo *info)
     info->error = "";
 
     /* The default directory for the user to select files. */
-    info->starting_dir = gnc_get_default_directory(GNC_PREFS_GROUP);
+    info->starting_dir = gnc_get_default_directory (GNC_PREFS_GROUP);
 }
 
 
@@ -307,28 +327,28 @@ gnc_input_dialog (GtkWidget *parent, const gchar *title, const gchar *msg, const
     GtkTextIter start, end;
 
     /* Create the widgets */
-    dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (parent),
+    dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW(parent),
                                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                           GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
                                           NULL);
 
-    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+    content_area = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
 
     // add a label
     label = gtk_label_new (msg);
-    gtk_container_add (GTK_CONTAINER (content_area), label);
+    gtk_container_add (GTK_CONTAINER(content_area), label);
 
     // add a textview
     view = gtk_text_view_new ();
-    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (view), GTK_WRAP_WORD_CHAR);
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(view), GTK_WRAP_WORD_CHAR);
+    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(view));
     gtk_text_buffer_set_text (buffer, default_input, -1);
-    gtk_container_add (GTK_CONTAINER (content_area), view);
+    gtk_container_add (GTK_CONTAINER(content_area), view);
 
     // run the dialog
     gtk_widget_show_all (dialog);
-    result = gtk_dialog_run (GTK_DIALOG (dialog));
+    result = gtk_dialog_run (GTK_DIALOG(dialog));
 
     if (result == GTK_RESPONSE_REJECT)
         user_input = 0;
@@ -374,7 +394,7 @@ csv_import_assistant_file_page_prepare (GtkAssistant *assistant,
 
     /* Set the default directory */
     if (info->starting_dir)
-        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(info->file_chooser), info->starting_dir);
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(info->file_chooser), info->starting_dir);
 
     /* Disable the Forward Assistant Button */
     gtk_assistant_set_page_complete (assistant, page, FALSE);
@@ -417,10 +437,10 @@ csv_import_assistant_finish_page_prepare (GtkAssistant *assistant,
         text = g_strdup_printf (gettext (finish_tree_string), info->file_name);
     }
     gtk_label_set_text (GTK_LABEL(info->finish_label), text);
-    g_free(text);
+    g_free (text);
 
     /* Save the Window size and directory */
-    gnc_set_default_directory(GNC_PREFS_GROUP, info->starting_dir);
+    gnc_set_default_directory (GNC_PREFS_GROUP, info->starting_dir);
 
     /* Enable the Assistant Buttons */
     gtk_assistant_set_page_complete (assistant, page, TRUE);
@@ -437,29 +457,29 @@ csv_import_assistant_summary_page_prepare (GtkAssistant *assistant,
     /* Before creating accounts, if this is a new book, let user specify
      * book options, since they affect how transactions are created */
     if (info->new_book)
-        info->new_book = gnc_new_book_option_display(info->window);
+        info->new_book = gnc_new_book_option_display (info->window);
 
-    if (!g_strcmp0(info->error, "") == 0)
+    if (!g_strcmp0 (info->error, "") == 0)
     {
         GtkTextBuffer *buffer;
 
-        buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (info->summary_error_view));
-        text = g_strdup_printf(gettext ("Import completed but with errors!\n\nThe number of Accounts added was %u and "
+        buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(info->summary_error_view));
+        text = g_strdup_printf (gettext ("Import completed but with errors!\n\nThe number of Accounts added was %u and "
                                         "updated was %u.\n\nSee below for errors..." ), info->num_new, info->num_updates );
-        errtext = g_strdup_printf ( "%s", info->error);
+        errtext = g_strdup_printf ("%s", info->error);
         gtk_text_buffer_set_text (buffer, errtext, -1);
-        g_free(errtext);
-        g_free(info->error);
+        g_free (errtext);
+        g_free (info->error);
     }
     else
-        text = g_strdup_printf(gettext ("Import completed successfully!\n\nThe number of Accounts added was %u and "
+        text = g_strdup_printf (gettext ("Import completed successfully!\n\nThe number of Accounts added was %u and "
                                         "updated was %u.\n" ), info->num_new, info->num_updates );
 
-    mtext = g_strdup_printf("<span size=\"medium\"><b>%s</b></span>", text);
-    gtk_label_set_markup(GTK_LABEL(info->summary_label), mtext);
+    mtext = g_strdup_printf ("<span size=\"medium\"><b>%s</b></span>", text);
+    gtk_label_set_markup (GTK_LABEL(info->summary_label), mtext);
 
-    g_free(text);
-    g_free(mtext);
+    g_free (text);
+    g_free (mtext);
 }
 
 
@@ -467,7 +487,7 @@ void
 csv_import_assistant_prepare (GtkAssistant *assistant, GtkWidget *page,
                               gpointer user_data)
 {
-    gint currentpage = gtk_assistant_get_current_page(assistant);
+    gint currentpage = gtk_assistant_get_current_page (assistant);
 
     switch (currentpage)
     {
@@ -535,11 +555,11 @@ csv_import_close_handler (gpointer user_data)
 {
     CsvImportInfo *info = user_data;
 
-    g_free(info->starting_dir);
-    g_free(info->file_name);
-    g_string_free(info->regexp, TRUE);
+    g_free (info->starting_dir);
+    g_free (info->file_name);
+    g_string_free (info->regexp, TRUE);
 
-    gnc_save_window_size(GNC_PREFS_GROUP, GTK_WINDOW(info->window));
+    gnc_save_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->window));
     gtk_widget_destroy (info->window);
 }
 
@@ -555,10 +575,11 @@ csv_import_assistant_create (CsvImportInfo *info)
     GtkWidget *button;
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
+    gchar *mnemonic_desc = NULL;
 
     builder = gtk_builder_new();
-    gnc_builder_add_from_file  (builder , "assistant-csv-account-import.glade", "num_hrows_adj");
-    gnc_builder_add_from_file  (builder , "assistant-csv-account-import.glade", "CSV Account Import Assistant");
+    gnc_builder_add_from_file  (builder, "assistant-csv-account-import.glade", "num_hrows_adj");
+    gnc_builder_add_from_file  (builder, "assistant-csv-account-import.glade", "CSV Account Import Assistant");
     window = GTK_WIDGET(gtk_builder_get_object (builder, "CSV Account Import Assistant"));
     info->window = window;
 
@@ -569,19 +590,19 @@ csv_import_assistant_create (CsvImportInfo *info)
     load_settings (info);
 
     /* Enable buttons on all page. */
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (window),
+    gtk_assistant_set_page_complete (GTK_ASSISTANT(window),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "start_page")),
                                      TRUE);
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (window),
+    gtk_assistant_set_page_complete (GTK_ASSISTANT(window),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "file_page")),
                                      FALSE);
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (window),
+    gtk_assistant_set_page_complete (GTK_ASSISTANT(window),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "import_tree_page")),
                                      TRUE);
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (window),
+    gtk_assistant_set_page_complete (GTK_ASSISTANT(window),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "end_page")),
                                      FALSE);
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (window),
+    gtk_assistant_set_page_complete (GTK_ASSISTANT(window),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "summary_page")),
                                      TRUE);
 
@@ -589,38 +610,42 @@ csv_import_assistant_create (CsvImportInfo *info)
 
     /* File chooser Page */
     info->file_chooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_OPEN);
-    g_signal_connect (G_OBJECT (info->file_chooser), "file-activated",
-                      G_CALLBACK (csv_import_file_chooser_confirm_cb), info);
-    button = gtk_button_new_from_stock(GTK_STOCK_OK);
+    g_signal_connect (G_OBJECT(info->file_chooser), "file-activated",
+                      G_CALLBACK(csv_import_file_chooser_confirm_cb), info);
+    button = gtk_button_new_from_stock (GTK_STOCK_OK);
     gtk_widget_set_size_request (button, 100, -1);
     gtk_widget_show (button);
-    h_box = gtk_hbox_new(TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(h_box), button, FALSE, FALSE, 0);
+    h_box = gtk_hbox_new (TRUE, 0);
+    gtk_box_pack_start (GTK_BOX(h_box), button, FALSE, FALSE, 0);
     gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER(info->file_chooser), h_box);
-    g_signal_connect (G_OBJECT (button), "clicked",
-                      G_CALLBACK (csv_import_file_chooser_confirm_cb), info);
+    g_signal_connect (G_OBJECT(button), "clicked",
+                      G_CALLBACK(csv_import_file_chooser_confirm_cb), info);
 
     box = GTK_WIDGET(gtk_builder_get_object(builder, "file_page"));
-    gtk_box_pack_start (GTK_BOX (box), info->file_chooser, TRUE, TRUE, 6);
+    gtk_box_pack_start (GTK_BOX(box), info->file_chooser, TRUE, TRUE, 6);
     gtk_widget_show (info->file_chooser);
 
     /* Account Tree Page */
     info->header_row_spin = GTK_WIDGET(gtk_builder_get_object (builder, "num_hrows"));
     info->tree_view = GTK_WIDGET(gtk_builder_get_object (builder, "treeview"));
 
-    info->regexp = g_string_new ( "^(?<type>[^;]*);(?<full_name>[^;]*);(?<name>[^;]*);(?<code>[^;]*);?(?<description>[^;]*);?(?<color>[^;]*);?(?<notes>[^;]*);?(?<commoditym>[^;]*);?(?<commodityn>[^;]*);?(?<hidden>[^;]*);?(?<tax>[^;]*);?(?<place_holder>[^;]*)$");
+    /* Comma Separated file default */
+    info->regexp = g_string_new ("");
+    create_regex (info->regexp, ",");
 
     /* create model and bind to view */
     info->store = gtk_list_store_new (N_COLUMNS,
                                       G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
                                       G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
-    gtk_tree_view_set_model( GTK_TREE_VIEW(info->tree_view), GTK_TREE_MODEL(info->store) );
+    gtk_tree_view_set_model (GTK_TREE_VIEW(info->tree_view), GTK_TREE_MODEL(info->store));
 #define CREATE_COLUMN(description,column_id) \
   renderer = gtk_cell_renderer_text_new (); \
-  column = gtk_tree_view_column_new_with_attributes (mnemonic_escape(_(description)), renderer, "text", column_id, NULL); \
-  gtk_tree_view_column_add_attribute(column, renderer, "background", ROW_COLOR); \
+  mnemonic_desc = mnemonic_escape (_(description)); \
+  column = gtk_tree_view_column_new_with_attributes (mnemonic_desc, renderer, "text", column_id, NULL); \
+  gtk_tree_view_column_add_attribute (column, renderer, "background", ROW_COLOR); \
   gtk_tree_view_column_set_resizable (column, TRUE); \
-  gtk_tree_view_append_column (GTK_TREE_VIEW (info->tree_view), column);
+  gtk_tree_view_append_column (GTK_TREE_VIEW(info->tree_view), column); \
+  g_free (mnemonic_desc);
     CREATE_COLUMN ("type", TYPE);
     CREATE_COLUMN ("full_name", FULL_NAME);
     CREATE_COLUMN ("name", NAME);
@@ -635,18 +660,18 @@ csv_import_assistant_create (CsvImportInfo *info)
     CREATE_COLUMN ("place_holder", PLACE_HOLDER);
 
     /* Finish Page */
-    info->finish_label = GTK_WIDGET(gtk_builder_get_object(builder, "end_page"));
+    info->finish_label = GTK_WIDGET(gtk_builder_get_object (builder, "end_page"));
     /* Summary Page */
-    info->summary_label = GTK_WIDGET(gtk_builder_get_object(builder, "summary_label"));
-    info->summary_error_view = GTK_WIDGET(gtk_builder_get_object(builder, "summary_error_view"));
+    info->summary_label = GTK_WIDGET(gtk_builder_get_object (builder, "summary_label"));
+    info->summary_error_view = GTK_WIDGET(gtk_builder_get_object (builder, "summary_error_view"));
 
     g_signal_connect (G_OBJECT(window), "destroy",
-                      G_CALLBACK (csv_import_assistant_destroy_cb), info);
+                      G_CALLBACK(csv_import_assistant_destroy_cb), info);
 
     gnc_restore_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->window));
 
-    gtk_builder_connect_signals(builder, info);
-    g_object_unref(G_OBJECT(builder));
+    gtk_builder_connect_signals (builder, info);
+    g_object_unref (G_OBJECT(builder));
     return window;
 }
 
