@@ -1074,8 +1074,8 @@ gnc_split_register_get_vnotes_entry (VirtualLocation virt_loc,
     trans = xaccSplitGetParent (split);
 
     if(trans == NULL)
-        return g_strdup('\0');
-    else 
+        return NULL;
+    else
         return xaccTransGetVoidReason(trans);
 }
 
