@@ -506,15 +506,15 @@ gnucash_cursor_init (GnucashCursor *cursor)
 
 
 static void
-gnucash_cursor_class_init (GnucashCursorClass *class)
+gnucash_cursor_class_init (GnucashCursorClass *klass)
 {
     GObjectClass  *object_class;
     GnomeCanvasItemClass *item_class;
 
-    object_class = G_OBJECT_CLASS (class);
-    item_class = GNOME_CANVAS_ITEM_CLASS (class);
+    object_class = G_OBJECT_CLASS (klass);
+    item_class = GNOME_CANVAS_ITEM_CLASS (klass);
 
-    gnucash_cursor_parent_class = g_type_class_peek_parent (class);
+    gnucash_cursor_parent_class = g_type_class_peek_parent (klass);
 
     /* GObject method overrides */
     object_class->set_property = gnucash_cursor_set_property;
