@@ -527,14 +527,14 @@
     (cons 'N262 #(none "F1040" "IRA contribution, self" 1 #f "IRA Contrib" ((2005 "32") (2004 "25") (2002 "24") (1997 "23") (1994 "23a") (1990 "24a") (1989 "24") (1987 "25a") (1985 "26") (1983 "26a") (1982 "25") (1981 "24") (1980 "25"))))
     (cons 'N481 #(none "F1040" "IRA contribution, spouse" 1 #f "" ((2005 "32") (2004 "25") (2002 "24") (1997 "23") (1994 "23b") (1990 "24b") (1989 "25") (1987 "25b") (1983 "26a") (1982 "25") (1981 "24") (1980 "25"))))
     (cons 'N636 #(none "F1040" "Student loan interest" 1 #f "Student loan in" ((2005 "33") (2004 "26") (2002 "25") (1998 "24"))))
-    (cons 'N613 #(none "F1040" "Fed tax withheld, RR retire, self" 1 #f "Tax:Fed wh, RR" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N614 #(none "F1040" "Fed tax withheld, RR retire, spouse" 1 #f "Tax Spouse:Fed" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N611 #(none "F1040" "Fed tax withheld, Soc. Sec., self" 1 #f "Tax:Fed wh, Soc" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N612 #(none "F1040" "Fed tax withheld, Soc. Sec., spouse" 1 #f "Tax Spouse:Fed" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N615 #(current "F1040" "Fed tax withheld, dividend income" 3 #f "" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N616 #(current "F1040" "Fed tax withheld, interest income" 3 #f "" ((2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
-    (cons 'N521 #(none "F1040" "Federal estimated tax, qrtrly" 6 #f "Tax:Fed Estimat" ((2011 "63") (2009 "62") (2008 "63") (2005 "65") (2004 "64") (2003 "62") (2002 "63") (2001 "60") (2000 "59") (1998 "58") (1997 "55") (1996 "53") (1995 "56") (1991 "55") (1990 "56") (1989 "57") (1987 "55") (1986 "57") (1983 "58") (1982 "61") (1980 "56"))))
-    (cons 'N268 #(none "F1040" "Fed. estimated tax" 1 #f "" ((2011 "63") (2009 "62") (2008 "63") (2005 "65") (2004 "64") (2003 "62") (2002 "63") (2001 "60") (2000 "59") (1998 "58") (1997 "55") (1996 "53") (1995 "56") (1991 "55") (1990 "56") (1989 "57") (1987 "55") (1986 "57") (1983 "58") (1982 "61") (1980 "56"))))
+    (cons 'N613 #(none "F1040" "Fed tax withheld, RR retire, self" 1 #f "Tax:Fed wh, RR" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N614 #(none "F1040" "Fed tax withheld, RR retire, spouse" 1 #f "Tax Spouse:Fed" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N611 #(none "F1040" "Fed tax withheld, Soc. Sec., self" 1 #f "Tax:Fed wh, Soc" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N612 #(none "F1040" "Fed tax withheld, Soc. Sec., spouse" 1 #f "Tax Spouse:Fed" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N615 #(current "F1040" "Fed tax withheld, dividend income" 3 #f "" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N616 #(current "F1040" "Fed tax withheld, interest income" 3 #f "" ((2014 "64") (2011 "62") (2009 "61") (2008 "62") (2005 "64") (2004 "63") (2003 "61") (2002 "62") (2001 "59") (2000 "58") (1998 "57") (1997 "54") (1996 "52") (1995 "55") (1991 "54") (1990 "55") (1989 "56") (1987 "54") (1986 "56") (1983 "57") (1982 "60") (1980 "55"))))
+    (cons 'N521 #(none "F1040" "Federal estimated tax, qrtrly" 6 #f "Tax:Fed Estimat" ((2014 "65") (2011 "63") (2009 "62") (2008 "63") (2005 "65") (2004 "64") (2003 "62") (2002 "63") (2001 "60") (2000 "59") (1998 "58") (1997 "55") (1996 "53") (1995 "56") (1991 "55") (1990 "56") (1989 "57") (1987 "55") (1986 "57") (1983 "58") (1982 "61") (1980 "56"))))
+    (cons 'N268 #(none "F1040" "Fed. estimated tax" 1 #f "" ((2014 "65") (2011 "63") (2009 "62") (2008 "63") (2005 "65") (2004 "64") (2003 "62") (2002 "63") (2001 "60") (2000 "59") (1998 "58") (1997 "55") (1996 "53") (1995 "56") (1991 "55") (1990 "56") (1989 "57") (1987 "55") (1986 "57") (1983 "58") (1982 "61") (1980 "56"))))
 
     (cons 'N270 #(not-impl "Sched A" "Schedule A" 1 #f ""))
     (cons 'N273 #(none "Sched A" "Medicine and drugs" 1 #f "Medical:Medicin" ((1990 "1") (1987 "1a") (1982 "1") (1980 "2"))))
@@ -583,8 +583,8 @@
     (cons 'N294 #(none "Sched C" "Meals and entertainment" 1 #t "" ((1990 "24b") (1989 "25b") (1987 "26b") (1986 "26") (1985 "27") (1982 "26") (1981 "27") (1980 "29"))))
     (cons 'N318 #(none "Sched C" "Utilities" 1 #t "" ((1990 "25") (1989 "26") (1986 "27") (1985 "28") (1982 "27") (1981 "28") (1980 "30"))))
     (cons 'N297 #(none "Sched C" "Wages paid" 1 #t "" ((1990 "26") (1989 "27") (1986 "28a") (1985 "29a") (1982 "28a") (1981 "29a") (1980 "31a"))))
-    (cons 'N302 #(current "Sched C" "Other business expenses" 3 #t "" ((1993 "27") (1990 "27b") (1989 "28") (1987 "29") (1986 "30") (1985 "31") (1982 "30") (1981 "31") (1980 "32"))))
-    (cons 'N305 #(none "Sched C" "Bad debts" 1 #t "" ((2003 "27") (1989 "9") (1982 "7") (1980 "8"))))
+    (cons 'N302 #(current "Sched C" "Other business expenses" 3 #t "" ((2011 "27a") (1993 "27") (1990 "27b") (1989 "28") (1987 "29") (1986 "30") (1985 "31") (1982 "30") (1981 "31") (1980 "32"))))
+    (cons 'N305 #(none "Sched C" "Bad debts" 1 #t "" ((2011 "27a") (2003 "27") (1989 "9") (1982 "7") (1980 "8"))))
     (cons 'N493 #(none "Sched C" "Purchases, cost of goods" 1 #t "" ((1996 "36") (1991 "34") (1990 "32") (1989 "33") (1983 "III,2") (1982 "C-1,2") (1980 "C-1,2a"))))
     (cons 'N295 #(none "Sched C" "Cost of goods sold" 1 #t "" ((1990 "37") (1989 "36") (1988 "III,5") (1980 "C-1,5")) 1992))
     (cons 'N494 #(none "Sched C" "Labor, cost of goods sold" 1 #t "" ((1996 "37") (1991 "35") (1990 "33") (1989 "34") (1983 "III,3") (1980 "C-1,3"))))
@@ -927,7 +927,6 @@
     (cons 'N1785 #(parent "F8825" "Wages and salaries – C" 1 #t "" ((1990 "13C"))))
     (cons 'N1786 #(parent "F8825" "Other miscellaneous expenses – C" 1 #t "" ((1990 "15C"))))
 
-    (cons 'N1789 #(parent "F8825" "Gross rents – D" 1 #t "" ((1990 "2D"))))
     (cons 'N1790 #(parent "F8825" "Advertising – D" 1 #t "" ((1990 "3D"))))
     (cons 'N1791 #(parent "F8825" "Auto and travel – D" 1 #t "" ((1990 "4D"))))
     (cons 'N1792 #(parent "F8825" "Cleaning and maintenance – D" 1 #t "" ((1990 "5D"))))
@@ -950,7 +949,7 @@
     (cons 'N674 #(none "Sched K-1" "28% rate gain(loss)" 1 #t "" ((2004 "9b") (2003 "25") (2001 "4e2") (1997 "4e1"))))
     (cons 'N456 #(parent "Sched K-1" "Net Section 1231 gain or loss" 1 #t "" ((2004 "10") (2003 "6b") (1998 "6") (1997 "6b") (1990 "6"))))
     (cons 'N676 #(none "Sched K-1" "Other Income (loss)" 1 #t "" ((2004 "11") (1990 "7"))))
-    (cons 'N679 #(none "Sched K-1" "Total Foreign Taxes" 1 #t "" ((2004 "16") (2001 "17g") (2000 "17f") (1990 "17e"))))
+    (cons 'N679 #(none "Sched K-1" "Total Foreign Taxes" 1 #t "" ((2004 "16l") (2001 "17g") (2000 "17f") (1990 "17e"))))
    )
   )
   (cons 'F1120
